SystemOrganization addCategory: #ConfigurationOfUsedObjects!

Object subclass: #ConfigurationOfUsedObjects
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfUsedObjects'!

!ConfigurationOfUsedObjects class methodsFor: 'private' stamp: 'MarianoMartinezPeck 10/12/2010 17:50'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfUsedObjects class methodsFor: 'private' stamp: 'MarianoMartinezPeck 10/12/2010 17:51'!
ensureMetacello
        "Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
         Gofer API), then load the latest version of Metacello itself."

        Smalltalk at: #MetacelloProject ifAbsent: [ | error |
                "list of repositories to try, in case primary repository is not accessible"
                (Array 
                        with: 'http://www.squeaksource.com/MetacelloRepository' 
                        with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
                                ([
                                        Smalltalk at: #Gofer ifAbsent: [
                                        "Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
                                                self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
                                        Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
                                                gofer := goferClass new
                                                        url: repositoryUrl;
                                                        yourself.
                                                [ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
                                                gofer load ]]
                                                        on: Error
                                                        do: [ :ex |
                                                                error := ex.
                                                                Transcript 
                                                                        cr; 
                                                                        show: 'failed ensureMetacello: ';
                                                                        show: ex description printString;
                                                                        show: '...retrying'.
                                                                "try again"
                                                                ex return: nil ]) ~~ nil
                                        ifTrue: [
                                                "load 'default' group of Metacello"
                                                (Smalltalk at: #ConfigurationOfMetacello) perform: #load.
                                                ^self ]].
                "shouldn't get here unless the load failed ... throw an error"
                self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfUsedObjects class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 10/12/2010 17:50'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfUsedObjects class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 10/12/2010 17:50'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfUsedObjects class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 10/12/2010 17:50'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfUsedObjects class methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 10/12/2010 17:50'!
project

	^self new project! !

!ConfigurationOfUsedObjects methodsFor: 'baselines' stamp: 'MarianoMartinezPeck 10/12/2010 18:09'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/UsedObjects'.
		spec project: 'VMMakerOriginal' with: [
				spec
					className: 'ConfigurationOfVMMaker';
					loads: #('default' );
					file: 'ConfigurationOfVMMaker';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
			
		
		spec package: 'UnusedObject'.
		spec package: 'UnusedObjectTests' with: [ spec requires: #('UnusedObject') ].
		spec package: 'VMMaker' with: [ spec requires: #('VMMakerOriginal') ].		
		spec package: 'UnusedObjectVMMaker' with: [ spec requires: #('VMMaker') ].					
	
		spec
 			group: 'default' with: #('UnusedObject');
			group: 'Tests' with: #('UnusedObjectTests');
			group: 'VMMakerGroup' with: #('UnusedObjectVMMaker').
		
	]! !

!ConfigurationOfUsedObjects methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 10/12/2010 17:50'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfUsedObjects methodsFor: 'versions' stamp: 'MarianoMartinezPeck 10/12/2010 18:13'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Mariano Martinez Peck'.
		spec description: ' '.
	].
	
	spec for: #pharo do: [		
				
		
		spec package: 'UnusedObject' with: 'UnusedObject-MarianoMartinezPeck.46'.
		spec package: 'UnusedObjectTests' with: 'UnusedObjectTests-MarianoMartinezPeck.14'.
		spec project: 'VMMakerOriginal' with: '1.4'.
		spec package: 'VMMaker' with: 'VMMaker-MarianoMartinezPeck.166'.
		spec package: 'UnusedObjectVMMaker' with: 'UnusedObjectVMMaker-MarianoMartinezPeck.2'.
		
					
		
	]
			! !
